@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,25 +14,22 @@
  * limitations under the License.
  */
 
-#include "bson/bson-prelude.h"
+#include <bson/bson-prelude.h>
 
 
 #ifndef BSON_KEYS_H
 #define BSON_KEYS_H
 
 
-#include "bson/bson-macros.h"
-#include "bson/bson-types.h"
+#include <bson/bson-macros.h>
+#include <bson/bson-types.h>
 
 
 BSON_BEGIN_DECLS
 
 
 BSON_EXPORT (size_t)
-bson_uint32_to_string (uint32_t value,
-                       const char **strptr,
-                       char *str,
-                       size_t size);
+bson_uint32_to_string (uint32_t value, const char **strptr, char *str, size_t size);
 
 
 BSON_END_DECLS
